@@ -17,23 +17,17 @@
 # under the License.
 from __future__ import annotations
 
-from collections.abc import Sequence
+from collections.abc import Callable, Sequence
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Callable
+from typing import TYPE_CHECKING, Any
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException, BaseSensorOperator
 from airflow.providers.http.hooks.http import HttpHook
 from airflow.providers.http.triggers.http import HttpSensorTrigger
-from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
-    try:
-        from airflow.sdk.definitions.context import Context
-        from airflow.sensors.base import PokeReturnValue
-    except ImportError:
-        # TODO: Remove once provider drops support for Airflow 2
-        from airflow.utils.context import Context
+    from airflow.sdk import Context, PokeReturnValue
 
 
 class HttpSensor(BaseSensorOperator):
@@ -167,7 +161,7 @@ class HttpSensor(BaseSensorOperator):
     def execute(self, context: Context) -> Any:
         if not self.deferrable or self.response_check:
             return super().execute(context=context)
-        elif not self.poke(context):
+        if not self.poke(context):
             self.defer(
                 timeout=timedelta(seconds=self.timeout),
                 trigger=HttpSensorTrigger(
